@@ -50,6 +50,8 @@ class CmdStanModel:
       model given data.
     - By default, compiles model on instantiation - override with argument
       ``compile=False``
+    - By default, property ``name`` corresponds to basename of the Stan program
+      or exe file - override with argument ``model_name=<name>``.
     """
 
     def __init__(
@@ -72,6 +74,12 @@ class CmdStanModel:
         self._logger = logger or get_logger()
 
         if model_name is not None:
+            if not model_name.strip():
+                raise ValueError(
+                    'Invalid value for argument model name, found "{}"'.format(
+                        model_name
+                    )
+                )
             self._name = model_name.strip()
 
         if stan_file is None:
@@ -158,7 +166,11 @@ class CmdStanModel:
 
     @property
     def name(self) -> str:
-        """Stan program name; corresponds to bare filename, no extension."""
+        """
+        Model name used in output filename templates. Default is basename
+        of Stan program or exe file, unless specified in call to constructor
+        via argument `model_name`.
+        """
         return self._name
 
     @property
@@ -458,12 +470,11 @@ class CmdStanModel:
         :param parallel_chains: Number of processes to run in parallel. Must be
             a positive integer.  Defaults to ``multiprocessing.cpu_count()``.
 
-        :threads_per_chain: If the model was compiled with threading support,
-            the number of threads to use in parallelized sections within an
-            MCMC chain (e.g., when using the Stan functions ``reduce_sum()``
-            or ``map_rect()``).  The total number of threads used will be
-            ``parallel_chains * threads_per_chain``.  If a model wasn't
-            compiled with threading support, has no effect.
+        :param threads_per_chain: The number of threads to use in parallelized
+            sections within an MCMC chain (e.g., when using the Stan functions
+            ``reduce_sum()``  or ``map_rect()``).  This will only have an effect
+            if the model was compiled with threading support. The total number
+            of threads used will be ``parallel_chains * threads_per_chain``.
 
         :param seed: The seed for random number generator. Must be an integer
             between 0 and 2^32 - 1. If unspecified,
@@ -586,12 +597,12 @@ class CmdStanModel:
             chain_ids = [x + 1 for x in range(chains)]
         else:
             if isinstance(chain_ids, int):
-                if chain_ids < 0:
+                if chain_ids < 1:
                     raise ValueError(
-                        'Chain_id must be a non-negative integer value,'
+                        'Chain_id must be a positive integer value,'
                         ' found {}.'.format(chain_ids)
                     )
-                chain_ids = [chain_ids + i + 1 for i in range(chains)]
+                chain_ids = [chain_ids + i for i in range(chains)]
             else:
                 if not len(chain_ids) == chains:
                     raise ValueError(
@@ -680,7 +691,7 @@ class CmdStanModel:
                 refresh=refresh,
                 logger=self._logger,
             )
-            runset = RunSet(args=args, chains=chains)
+            runset = RunSet(args=args, chains=chains, chain_ids=chain_ids)
             pbar = None
             all_pbars = []
 
@@ -807,16 +818,19 @@ class CmdStanModel:
             sample_csv_files = mcmc_sample.runset.csv_files
             sample_drawset = mcmc_sample.get_drawset()
             chains = mcmc_sample.chains
+            chain_ids = mcmc_sample.chain_ids
         elif isinstance(mcmc_sample, list):
+            if len(mcmc_sample) < 1:
+                raise ValueError('MCMC sample cannot be empty list')
             sample_csv_files = mcmc_sample
+            chains = len(sample_csv_files)
+            chain_ids = [x + 1 for x in range(chains)]
         else:
             raise ValueError(
                 'MCMC sample must be either CmdStanMCMC object'
                 ' or list of paths to sample csv_files.'
             )
-
         try:
-            chains = len(sample_csv_files)
             if sample_drawset is None:  # assemble sample from csv files
                 config = {}
                 # scan 1st csv file to get config
@@ -841,10 +855,10 @@ class CmdStanModel:
                 args = CmdStanArgs(
                     self._name,
                     self._exe_file,
-                    chain_ids=[x + 1 for x in range(chains)],
+                    chain_ids=chain_ids,
                     method_args=sampler_args,
                 )
-                runset = RunSet(args=args, chains=chains)
+                runset = RunSet(args=args, chains=chains, chain_ids=chain_ids)
                 runset._csv_files = sample_csv_files
                 sample_fit = CmdStanMCMC(runset)
                 sample_drawset = sample_fit.get_drawset()
@@ -864,13 +878,13 @@ class CmdStanModel:
             args = CmdStanArgs(
                 self._name,
                 self._exe_file,
-                chain_ids=[x + 1 for x in range(chains)],
+                chain_ids=chain_ids,
                 data=_data,
                 seed=seed,
                 output_dir=gq_output_dir,
                 method_args=generate_quantities_args,
             )
-            runset = RunSet(args=args, chains=chains)
+            runset = RunSet(args=args, chains=chains, chain_ids=chain_ids)
 
             parallel_chains_avail = cpu_count()
             parallel_chains = max(min(parallel_chains_avail - 2, chains), 1)
