@@ -421,7 +421,7 @@ class CmdStanMCMCTest(unittest.TestCase):
             output_dir=DATAFILES_PATH,
             method_args=sampler_args,
         )
-        runset = RunSet(args=cmdstan_args, chains=4)
+        runset = RunSet(args=cmdstan_args)
         runset._csv_files = [
             os.path.join(DATAFILES_PATH, 'runset-good', 'bern-1.csv'),
             os.path.join(DATAFILES_PATH, 'runset-good', 'bern-2.csv'),
@@ -444,22 +444,35 @@ class CmdStanMCMCTest(unittest.TestCase):
             drawset.shape,
             (fit.runset.chains * fit.num_draws, len(fit.column_names)),
         )
-        _ = fit.summary()
-        self.assertTrue(True)
 
-        # TODO - use cmdstan test files instead
-        expected = '\n'.join(
-            [
-                'Checking sampler transitions treedepth.',
-                'Treedepth satisfactory for all transitions.',
-                '\nChecking sampler transitions for divergences.',
-                'No divergent transitions found.',
-                '\nChecking E-BFMI - sampler transitions HMC potential energy.',
-                'E-BFMI satisfactory for all transitions.',
-                '\nEffective sample size satisfactory.',
-            ]
+        summary = fit.summary()
+        self.assertIn('5%', list(summary.columns))
+        self.assertIn('50%', list(summary.columns))
+        self.assertIn('95%', list(summary.columns))
+        self.assertNotIn('1%', list(summary.columns))
+        self.assertNotIn('99%', list(summary.columns))
+
+        summary = fit.summary(percentiles=[1, 45, 99])
+        self.assertIn('1%', list(summary.columns))
+        self.assertIn('45%', list(summary.columns))
+        self.assertIn('99%', list(summary.columns))
+        self.assertNotIn('5%', list(summary.columns))
+        self.assertNotIn('50%', list(summary.columns))
+        self.assertNotIn('95%', list(summary.columns))
+
+        with self.assertRaises(ValueError):
+            fit.summary(percentiles=[])
+
+        with self.assertRaises(ValueError):
+            fit.summary(percentiles=[-1])
+
+        diagnostics = fit.diagnose()
+        self.assertIn(
+            'Treedepth satisfactory for all transitions.', diagnostics
         )
-        self.assertIn(expected, fit.diagnose().replace('\r\n', '\n'))
+        self.assertIn('No divergent transitions found.', diagnostics)
+        self.assertIn('E-BFMI satisfactory for all transitions.', diagnostics)
+        self.assertIn('Effective sample size satisfactory.', diagnostics)
 
     def test_validate_big_run(self):
         exe = os.path.join(DATAFILES_PATH, 'bernoulli' + EXTENSION)
@@ -640,7 +653,7 @@ class CmdStanMCMCTest(unittest.TestCase):
             output_dir=DATAFILES_PATH,
             method_args=sampler_args,
         )
-        runset = RunSet(args=cmdstan_args, chains=4)
+        runset = RunSet(args=cmdstan_args)
         for i in range(4):
             runset._set_retcode(i, 0)
         self.assertTrue(runset._check_retcodes())
